@@ -113,15 +113,17 @@ with_mock_crunch({
     })
 
     test_that("as.data.frame(force = TRUE) generates a POST", {
-
-        expect_POST(as.data.frame(ds, force = TRUE, include.hidden = FALSE),
-            'https://app.crunch.io/api/datasets/1/export/csv/',
-            '{"filter":null,"options":{"use_category_ids":true}}')
+        expect_POST(
+            as.data.frame(ds, force = TRUE, include.hidden = FALSE),
+            "https://app.crunch.io/api/datasets/1/export/csv/",
+            '{"filter":null,"options":{"use_category_ids":true}}'
+        )
     })
     csv_df <- read.csv("dataset-fixtures/test_ds.csv", stringsAsFactors = FALSE)
     test_that("csvToDataFrame produces the correct data frame", {
         expected <- readRDS("dataset-fixtures/test_ds.rds")
-        cdf <- as.data.frame(ds[, c("birthyr", "gender", "location", "mymrset", "textVar", "starttime")])
+        vars <- c("birthyr", "gender", "location", "mymrset", "textVar", "starttime")
+        cdf <- as.data.frame(ds[, vars])
         # test local CDF variables
         cdf$newvar <- expected$newvar <- c(1:24, NA)
         expect_identical(csvToDataFrame(csv_df, cdf), expected)
@@ -144,7 +146,6 @@ with_mock_crunch({
     test_that("as.data.frame() works with hidden variables", {
         new_ds <- loadDataset("test ds")
         new_ds$gender@tuple[["discarded"]] <- TRUE
-        expect_equivalent(hiddenVariables(new_ds), "gender")
         new_ds_df <- as.data.frame(new_ds, include.hidden = TRUE)
         expect_equal(
             names(new_ds_df),
@@ -188,10 +189,10 @@ with_mock_crunch({
 
 with_test_authentication({
     ds <- newDataset(df)
-    
+
     # change the alias of v6 to be something that includes spaces/punctuation
     alias(ds$v6) <- "vee six !"
-    
+
     test_that("Check the types of our imported data", {
         expect_true(is.Numeric(ds[["v1"]]))
         expect_true(is.Text(ds[["v2"]]))
@@ -219,7 +220,7 @@ with_test_authentication({
     values(categories(ds$v4b)[1:2]) <- c(5, 3)
     test_that("as.vector on a Categorical", {
         expect_true(is.factor(as.vector(ds$v4b)))
-        expect_equivalent(as.vector(ds$v4b)[-(3:5)], df$v4[-(3:5)])
+        expect_equivalent(as.vector(ds$v4b)[-(3:5)], df$v4[-(3:5)]) # nolint
         expect_true(all(is.na(as.vector(ds$v4b)[3:5])))
     })
     test_that("as.vector with mode specified on Categorical", {
@@ -245,7 +246,7 @@ with_test_authentication({
         expect_is(as.data.frame(ds), "CrunchDataFrame")
         expect_identical(dim(as.data.frame(ds)), dim(df))
         expect_identical(names(as.data.frame(ds)), aliases(variables(ds)))
-        
+
         # check that all of the values are the same
         expect_identical(as.data.frame(ds)$v1, as.vector(ds$v1))
         expect_identical(as.data.frame(ds)$v2, as.vector(ds$v2))
@@ -258,10 +259,10 @@ with_test_authentication({
     test_that("as.data.frame(force) with API", {
         skip_on_local_backend("Vagrant host doesn't serve files correctly")
         expect_true(is.data.frame(as.data.frame(as.data.frame(ds))))
-        
+
         df <- as.data.frame(ds, force = TRUE)
         expect_true(is.data.frame(df))
-        
+
         # check that all of the values are the same
         expect_identical(df$v1, as.vector(ds$v1))
         # we only compare the non-na (1:15) in the text variable, becuase the NA
@@ -288,12 +289,14 @@ with_test_authentication({
         # should be revisited
         expect_warning(
             df <- as.data.frame(ds, force = TRUE),
-            "Variable hidden_var is hidden")
+            "Variable hidden_var is hidden"
+        )
         expect_equal(names(df), c("v1", "v2", "v3", "v4", "v5", "vee six !", "hidden_var"))
 
         expect_warning(
             df <- as.data.frame(ds, force = TRUE, include.hidden = TRUE),
-            "Variable hidden_var is hidden")
+            "Variable hidden_var is hidden"
+        )
         expect_equal(names(df), c("v1", "v2", "v3", "v4", "v5", "vee six !", "hidden_var"))
 
         expect_warning(
@@ -302,7 +305,7 @@ with_test_authentication({
         )
         expect_equal(names(df), c("v1", "hidden_var"))
     })
-    
+
     test_that("Multiple response variables in as.data.frame(force=TRUE)", {
         skip_on_local_backend("Vagrant host doesn't serve files correctly")
         mrds <- mrdf.setup(newDataset(mrdf, name = "test-mrdfmr"), selections = "1.0")
