@@ -474,8 +474,12 @@ with_test_authentication({
             levels = (c("Cats", "Dogs", "Other"))
             )
         )
-        expect_equal(ids(categories(ds$catdog2)), c(1, 2, 99))
-        expect_equal(names(categories(ds$catdog2)), c("Cats", "Dogs", "Other"))
+        expect_equal_temp_nodata(
+            ids(categories(ds$catdog2)), c(1, 2, 99, -1)
+        )
+        expect_identical_temp_nodata(
+            names(categories(ds$catdog2)), c("Cats", "Dogs", "Other", "No Data")
+        )
 
         # positive ids can be missing
         ds$catdog3 <- makeCaseVariable(
