@@ -1,5 +1,6 @@
 context("Derived array variables maintain subvar links")
 
+# nolint start
 # derived ds instantaitor
 new_ds_with_derived_array <- function() {
     ds <- newDatasetFromFixture("apidocs")
@@ -9,6 +10,7 @@ new_ds_with_derived_array <- function() {
     )
     return(ds)
 }
+# nolint end
 
 with_test_authentication({
     ds <- new_ds_with_derived_array()
@@ -62,10 +64,10 @@ with_test_authentication({
     ds <- new_ds_with_derived_array()
 
     test_that("changing category names in metadata carries", {
-        names(categories(ds$petloc)) <- c(
-            "Kat", "Dogz", "Bird",
-            "Skipped", "Not Asked"
-        )
+        existing <- names(categories(ds$petloc))
+        existing[1] <- "Kat"
+        existing[2] <- "Dogz"
+        names(categories(ds$petloc)) <- existing
         ds <- refresh(ds) # must refresh to update the derived variable's metadata
 
         expect_true(is.derived(ds$derivedarray))
@@ -145,11 +147,11 @@ with_test_authentication({
             as.vector(ds$petloc, mode = "id")
         )
     })
-    
+
     # Test derive from categorical arrays that are stored as sparse categorical
-    # 
-    # Make a factor that is overwhelmingly NA, but with some combos we want to 
-    # collapse. Confirmed that this ratio is stored as sparse categorical, but 
+    #
+    # Make a factor that is overwhelmingly NA, but with some combos we want to
+    # collapse. Confirmed that this ratio is stored as sparse categorical, but
     # if the definitions for what counts as sparse change, this might need to be
     # changed to maintain coverage
     # fac <- factor(
@@ -166,8 +168,8 @@ with_test_authentication({
     # )
     # # need to change categories to IDs, and then remove NAs
     # write.csv(df, "tests/testthat/dataset-fixtures/sparse_ca.csv", row.names = FALSE)
-    
-    # we need to create with metadata to ensure that the categorical array is 
+
+    # we need to create with metadata to ensure that the categorical array is
     # stored as sparse categorical (if we use bind, then we have to figure out
     # how to trigger a cleanup which is not exposed to the API)
     ds <- createWithMetadataAndFile(
@@ -177,17 +179,17 @@ with_test_authentication({
         ),
         test_path(file.path("dataset-fixtures", "sparse_ca.csv"))
     )
-    
+
     test_that("combine on categorical array stored as sparse returns correct values", {
         # the first categorical array is the same as the copies
         first_copy_vals <- as.vector(ds$first_copy)
         second_copy_vals <- as.vector(ds$second_copy)
         expect_equal(as.vector(ds$cat_array$first), first_copy_vals)
         expect_equal(as.vector(ds$cat_array$second), second_copy_vals)
-        
+
         # make our combined variable
         ds$ca_combined <- combine(
-            ds$cat_array, 
+            ds$cat_array,
             combinations = list(
                 list(
                     name = "A",
@@ -207,20 +209,20 @@ with_test_authentication({
         # combine the values on the vector to compare with the combined variable
         levels(first_copy_vals) <- c("A", "B", "C", "A", "B", "C")
         levels(second_copy_vals) <- c("A", "B", "C", "A", "B", "C")
-        
+
         expect_equal(as.vector(ds$ca_combined$`first#`), first_copy_vals)
         expect_equal(as.vector(ds$ca_combined$`second#`), second_copy_vals)
-        
-        # and this might be clearer in a cube of the first subvar and the 
+
+        # and this might be clearer in a cube of the first subvar and the
         # first_copy, this test is testing the same thing as above, with a cube
-        # 
+        #
         # we expect:
         # first_copy
         # first# A B C a b c
         #      A 6 0 0 3 0 0
         #      B 0 5 0 0 2 0
         #      C 0 0 4 0 0 1
-        # 
+        #
         # we get:
         # first_copy
         # first# A B C a b c
@@ -228,12 +230,12 @@ with_test_authentication({
         #      B 0 0 0 0 2 0
         #      C 0 0 0 0 0 1
         dims <- list(
-            `first#` = c("A", "B", "C"), 
+            `first#` = c("A", "B", "C"),
             first_copy = c("A", "B", "C", "a", "b", "c")
         )
-        
+
         expect_equivalent(
-            as.array(crtabs(~ca_combined[['first#']]+first_copy, ds)), 
+            as.array(crtabs(~ ca_combined[["first#"]] + first_copy, ds)),
             cubify(
                 6, 0, 0, 3, 0, 0,
                 0, 5, 0, 0, 2, 0,
