@@ -47,7 +47,8 @@ with_mock_crunch({
             "https://app.crunch.io/api/datasets/1/multitables/4de322/",
             '{"is_public":false}'
         )
-        with_PATCH(NULL,
+        with_PATCH(
+            NULL,
             is.public(mults)[3] <- FALSE
         )
         expect_no_request(is.public(mults)[3] <- TRUE)
@@ -101,20 +102,22 @@ with_mock_crunch({
 
     test_that("newMultitable", {
         expect_POST(
-            newMultitable(~gender + mymrset,
+            newMultitable(~ gender + mymrset,
                 data = ds,
                 name = "New multitable"
             ),
             "https://app.crunch.io/api/datasets/1/multitables/",
             '{"element":"shoji:entity","body":{',
-            '"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
+            '"template":[{"query":[{"variable":"https://app.crunch.io/api/',
+            'datasets/1/variables/gender/"}]},',
             '{"query":[{"each":"https://app.crunch.io/api/datasets/1/variables/mymrset/"},',
-            '{"function":"as_selected","args":[{"variable":"https://app.crunch.io/api/datasets/1/variables/mymrset/"}]}',
+            '{"function":"as_selected","args":[{"variable":"https://app.crunch.io/',
+            'api/datasets/1/variables/mymrset/"}]}',
             "]}]",
             ',"name":"New multitable"}}'
         )
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~gender + mymrset,
+            mtable <- newMultitable(~ gender + mymrset,
                 data = ds,
                 name = "New multitable"
             )
@@ -124,17 +127,19 @@ with_mock_crunch({
 
     test_that("newMultitable provides a default name based on the formula", {
         expect_POST(
-            newMultitable(~gender + mymrset, data = ds),
+            newMultitable(~ gender + mymrset, data = ds),
             "https://app.crunch.io/api/datasets/1/multitables/",
             '{"element":"shoji:entity","body":{',
-            '"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
+            '"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets',
+            '/1/variables/gender/"}]},', # nolint
             '{"query":[{"each":"https://app.crunch.io/api/datasets/1/variables/mymrset/"},',
-            '{"function":"as_selected","args":[{"variable":"https://app.crunch.io/api/datasets/1/variables/mymrset/"}]}',
+            '{"function":"as_selected","args":[{"variable":"https://app.crunch.io',
+            '/api/datasets/1/variables/mymrset/"}]}', # nolint
             "]}]",
             ',"name":"gender + mymrset"}}'
         )
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~gender + mymrset,
+            mtable <- newMultitable(~ gender + mymrset,
                 data = ds,
                 name = "New multitable"
             )
@@ -144,7 +149,7 @@ with_mock_crunch({
 
     test_that("importMultitable", {
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~gender + mymrset,
+            mtable <- newMultitable(~ gender + mymrset,
                 data = ds,
                 name = "New multitable"
             )
@@ -161,7 +166,7 @@ with_mock_crunch({
 
     test_that("multitable show method", {
         with_POST("https://app.crunch.io/api/datasets/1/multitables/4de322/", {
-            mtable <- newMultitable(~gender + mymrset,
+            mtable <- newMultitable(~ gender + mymrset,
                 data = ds,
                 name = "Shared multitable"
             )
@@ -180,30 +185,33 @@ with_mock_crunch({
 
     test_that("multitable list methods", {
         expect_POST(
-            multitables(ds)[["mt again"]] <- ~gender + birthyr,
+            multitables(ds)[["mt again"]] <- ~ gender + birthyr,
             "https://app.crunch.io/api/datasets/1/multitables/",
             '{"element":"shoji:entity","body":',
-            '{"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
+            '{"template":[{"query":[{"variable":',
+            '"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
             '{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/birthyr/"}]}]',
             ',"name":"mt again"}}'
         )
         expect_PATCH(
-            multitables(ds)[["Shared multitable"]] <- ~gender + birthyr,
+            multitables(ds)[["Shared multitable"]] <- ~ gender + birthyr,
             "https://app.crunch.io/api/datasets/1/multitables/4de322/",
             '{"element":"shoji:entity","body":',
-            '{"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
+            '{"template":[{"query":[{"variable":',
+            '"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
             '{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/birthyr/"}]}]',
             "}}"
         )
         expect_PATCH(
-            multitables(ds)[[3]] <- ~gender + birthyr,
+            multitables(ds)[[3]] <- ~ gender + birthyr,
             "https://app.crunch.io/api/datasets/1/multitables/4de322/",
             '{"element":"shoji:entity","body":',
-            '{"template":[{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
+            '{"template":[{"query":[{"variable":',
+            '"https://app.crunch.io/api/datasets/1/variables/gender/"}]},',
             '{"query":[{"variable":"https://app.crunch.io/api/datasets/1/variables/birthyr/"}]}]',
             "}}"
         )
-        expect_error(multitables(ds)[[999]] <- ~gender + birthyr, "subscript out of bounds: 999")
+        expect_error(multitables(ds)[[999]] <- ~ gender + birthyr, "subscript out of bounds: 999")
     })
 
     test_that("newMultitable validation", {
@@ -436,7 +444,7 @@ with_test_authentication({
     })
 
     test_that("Can make a multitable", {
-        m <- newMultitable(~allpets + q1, data = ds)
+        m <- newMultitable(~ allpets + q1, data = ds)
         expect_identical(name(m), "allpets + q1")
         expect_identical(getShowContent(m), c(
             paste0("Multitable ", dQuote("allpets + q1")),
@@ -447,7 +455,7 @@ with_test_authentication({
     })
 
     test_that("Can make a multitable perserving zcl functions", {
-        m <- newMultitable(~rollup(wave, "M") + q1, data = ds)
+        m <- newMultitable(~ rollup(wave, "M") + q1, data = ds)
         expect_identical(name(m), "rollup(wave, \"M\") + q1")
         expect_identical(getShowContent(m), c(
             paste0("Multitable ", dQuote("rollup(wave, \"M\") + q1")),
@@ -460,7 +468,7 @@ with_test_authentication({
     })
 
     test_that("Can make a multitable with a cat array", {
-        m <- newMultitable(~petloc + q1, data = ds)
+        m <- newMultitable(~ petloc + q1, data = ds)
         expect_identical(name(m), "petloc + q1")
         expect_identical(getShowContent(m), c(
             paste0("Multitable ", dQuote("petloc + q1")),
@@ -473,7 +481,7 @@ with_test_authentication({
     })
 
     test_that("Can make a multitable with list methods", {
-        multitables(ds)[["new mt"]] <- ~country + q3
+        multitables(ds)[["new mt"]] <- ~ country + q3
         expect_identical(
             getShowContent(multitables(ds)[["new mt"]]),
             c(
@@ -483,7 +491,7 @@ with_test_authentication({
                 "  q3"
             )
         )
-        multitables(ds)[["new mt"]] <- ~country + q1
+        multitables(ds)[["new mt"]] <- ~ country + q1
         expect_identical(
             getShowContent(multitables(ds)[["new mt"]]),
             c(
@@ -571,7 +579,7 @@ with_test_authentication({
     })
 
     test_that("team-sharing of multitables", {
-        multitables(ds)[["team multitable"]] <- ~allpets + q1
+        multitables(ds)[["team multitable"]] <- ~ allpets + q1
         team_multitab <- multitables(ds)[["team multitable"]]
         expect_null(team(team_multitab))
 
