@@ -153,8 +153,10 @@ with_mock_crunch({
 
     d <- datasets(aproject)
     test_that("datasets() filters a project folder", {
-        expect_identical(names(d),
-            c("an archived dataset", "test ds", "streaming no messages"))
+        expect_identical(
+            names(d),
+            c("an archived dataset", "test ds", "streaming no messages")
+        )
     })
 
     test_that("Can loadDataset from a project dataset catalog", {
@@ -336,7 +338,7 @@ with_test_authentication({
         expect_identical(names(datasets(tp)), name(ds))
         expect_identical(owner(refresh(ds)), self(tp))
     })
-    ds2 <- loadDataset(name(ds), project=name(tp))
+    ds2 <- loadDataset(name(ds), project = name(tp))
     test_that("Can load a dataset from a project", {
         expect_true(is.dataset(ds2))
         expect_identical(self(ds2), self(ds))
