@@ -8,10 +8,14 @@ with_mock_crunch({
         expect_is(vm, "VariableCatalog")
         expect_identical(aliases(vm), aliases(allVariables(ds)))
         mymr <- index(vm)[[which(aliases(vm) == "mymrset")]]
-        expect_identical(mymr$subvariables,
-            c("https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar2/",
-            "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1/",
-            "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar3/"))
+        expect_identical(
+            mymr$subvariables,
+            c(
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar2/",
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1/",
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar3/"
+            )
+        )
     })
 })
 
@@ -21,8 +25,10 @@ without_internet({
         ds2 <- ds
         ds2@variables <- vm
         expect_identical(categories(ds2$gender), genders)
-        expect_identical(names(subvariables(ds2$mymrset)),
-            c("First", "Second", "Last"))
+        expect_identical(
+            names(subvariables(ds2$mymrset)),
+            c("First", "Second", "Last")
+        )
     })
 })
 
@@ -32,10 +38,14 @@ with_test_authentication({
         vm <- variableMetadata(ds)
         expect_is(vm, "VariableCatalog")
         i <- which(aliases(vm) == "allpets")
-        expect_identical(Categories(data=vm[[i]]$categories),
-            categories(ds$allpets))
-        expect_identical(vm[[i]]$subvariables,
-            subvariableURLs(tuple(ds$allpets)))
+        expect_identical(
+            Categories(data = vm[[i]]$categories),
+            categories(ds$allpets)
+        )
+        expect_identical(
+            vm[[i]]$subvariables,
+            subvariableURLs(tuple(ds$allpets))
+        )
         expect_true(all(grepl("^http", urls(vm))))
         expect_true(!any(is.na(getIndexSlot(vm, "id"))))
     })
